@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -54,6 +54,34 @@ class MariadbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CancelDcnJob(self, request):
+        """取消DCN同步
+
+        :param request: Request instance for CancelDcnJob.
+        :type request: :class:`tencentcloud.mariadb.v20170312.models.CancelDcnJobRequest`
+        :rtype: :class:`tencentcloud.mariadb.v20170312.models.CancelDcnJobResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CancelDcnJob", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CancelDcnJobResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CloneAccount(self, request):
         """本接口（CloneAccount）用于克隆实例账户。
 
@@ -195,6 +223,34 @@ class MariadbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateDedicatedClusterDBInstance(self, request):
+        """创建独享集群Mariadb实例
+
+        :param request: Request instance for CreateDedicatedClusterDBInstance.
+        :type request: :class:`tencentcloud.mariadb.v20170312.models.CreateDedicatedClusterDBInstanceRequest`
+        :rtype: :class:`tencentcloud.mariadb.v20170312.models.CreateDedicatedClusterDBInstanceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateDedicatedClusterDBInstance", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateDedicatedClusterDBInstanceResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateTmpInstances(self, request):
         """本接口（CreateTmpInstances）用于创建临时实例。
 
@@ -645,6 +701,34 @@ class MariadbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeDcnDetail(self, request):
+        """获取实例灾备详情
+
+        :param request: Request instance for DescribeDcnDetail.
+        :type request: :class:`tencentcloud.mariadb.v20170312.models.DescribeDcnDetailRequest`
+        :rtype: :class:`tencentcloud.mariadb.v20170312.models.DescribeDcnDetailResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeDcnDetail", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeDcnDetailResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeFlow(self, request):
         """本接口（DescribeFlow）用于查询流程状态。
 
@@ -673,6 +757,34 @@ class MariadbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeInstanceNodeInfo(self, request):
+        """本接口（DescribeInstanceNodeInfo）用于获取数据库实例主备节点信息
+
+        :param request: Request instance for DescribeInstanceNodeInfo.
+        :type request: :class:`tencentcloud.mariadb.v20170312.models.DescribeInstanceNodeInfoRequest`
+        :rtype: :class:`tencentcloud.mariadb.v20170312.models.DescribeInstanceNodeInfoResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeInstanceNodeInfo", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeInstanceNodeInfoResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeLogFileRetentionPeriod(self, request):
         """本接口(DescribeLogFileRetentionPeriod)用于查看数据库备份日志的备份天数的设置情况。
 
@@ -870,7 +982,7 @@ class MariadbClient(AbstractClient):
 
 
     def DescribeUpgradePrice(self, request):
-        """本接口（DescribeUpgradePrice）用于在扩容云数据库实例时，查询扩容的价格。
+        """本接口（DescribeUpgradePrice）用于在扩容云数据库实例时，查询变配的价格。
 
         :param request: Request instance for DescribeUpgradePrice.
         :type request: :class:`tencentcloud.mariadb.v20170312.models.DescribeUpgradePriceRequest`
@@ -897,6 +1009,34 @@ class MariadbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DestroyHourDBInstance(self, request):
+        """本接口（DestroyHourDBInstance）用于销毁按量计费实例。
+
+        :param request: Request instance for DestroyHourDBInstance.
+        :type request: :class:`tencentcloud.mariadb.v20170312.models.DestroyHourDBInstanceRequest`
+        :rtype: :class:`tencentcloud.mariadb.v20170312.models.DestroyHourDBInstanceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DestroyHourDBInstance", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DestroyHourDBInstanceResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DisassociateSecurityGroups(self, request):
         """本接口(DisassociateSecurityGroups)用于安全组批量解绑实例。
 
@@ -1010,6 +1150,34 @@ class MariadbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def KillSession(self, request):
+        """本接口（KillSession）用于杀死指定会话。
+
+        :param request: Request instance for KillSession.
+        :type request: :class:`tencentcloud.mariadb.v20170312.models.KillSessionRequest`
+        :rtype: :class:`tencentcloud.mariadb.v20170312.models.KillSessionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("KillSession", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.KillSessionResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyAccountDescription(self, request):
         """本接口（ModifyAccountDescription）用于修改云数据库账号备注。
         注意：相同用户名，不同Host是不同的账号。
@@ -1039,6 +1207,39 @@ class MariadbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyAccountPrivileges(self, request):
+        """本接口(ModifyAccountPrivileges)用于修改云数据库的账户的权限信息。
+
+        **注意**
+        - 系统保留库："mysql"，只开放["SELECT"]权限
+        - 只读账号授予读写权限会报错
+        - 不传该参数表示保留现有权限，如需清除，请在复杂类型Privileges字段传空数组
+
+        :param request: Request instance for ModifyAccountPrivileges.
+        :type request: :class:`tencentcloud.mariadb.v20170312.models.ModifyAccountPrivilegesRequest`
+        :rtype: :class:`tencentcloud.mariadb.v20170312.models.ModifyAccountPrivilegesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ModifyAccountPrivileges", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyAccountPrivilegesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyBackupTime(self, request):
         """本接口（ModifyBackupTime）用于设置云数据库实例的备份时间。后台系统将根据此配置定期进行实例备份。
 
@@ -1179,6 +1380,34 @@ class MariadbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyDBSyncMode(self, request):
+        """本接口（ModifyDBSyncMode）用于修改云数据库实例的同步模式。
+
+        :param request: Request instance for ModifyDBSyncMode.
+        :type request: :class:`tencentcloud.mariadb.v20170312.models.ModifyDBSyncModeRequest`
+        :rtype: :class:`tencentcloud.mariadb.v20170312.models.ModifyDBSyncModeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ModifyDBSyncMode", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyDBSyncModeResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyLogFileRetentionPeriod(self, request):
         """本接口(ModifyLogFileRetentionPeriod)用于修改数据库备份日志保存天数。
 
@@ -1207,6 +1436,67 @@ class MariadbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyRealServerAccessStrategy(self, request):
+        """本接口(ModifyRealServerAccessStrategy)用于修改云数据库的VPCGW到RS的访问策略。
+
+        **注意**
+        - 修改策略后只对新建立的连接生效，老连接不受影响
+        - 就近访问只针对实例是跨可用区部署有用，单可用区部署实例就近与否并无作用
+        - DB每个Node对应一个proxy，如果开启就近访问，将会把连接集中到对应可用区的proxy上，可能造成热点问题，这种情况下如果是线上业务，请务必根据自己的业务请求量测试符合预期后再进行就近策略变更
+
+        :param request: Request instance for ModifyRealServerAccessStrategy.
+        :type request: :class:`tencentcloud.mariadb.v20170312.models.ModifyRealServerAccessStrategyRequest`
+        :rtype: :class:`tencentcloud.mariadb.v20170312.models.ModifyRealServerAccessStrategyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ModifyRealServerAccessStrategy", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyRealServerAccessStrategyResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def ModifySyncTaskAttribute(self, request):
+        """本接口 (ModifySyncTaskAttribute) 用于修改同步任务的属性（目前只支持修改任务名称）
+
+        :param request: Request instance for ModifySyncTaskAttribute.
+        :type request: :class:`tencentcloud.mariadb.v20170312.models.ModifySyncTaskAttributeRequest`
+        :rtype: :class:`tencentcloud.mariadb.v20170312.models.ModifySyncTaskAttributeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ModifySyncTaskAttribute", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifySyncTaskAttributeResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def OpenDBExtranetAccess(self, request):
         """本接口（OpenDBExtranetAccess）用于开通云数据库实例的外网访问。开通外网访问后，您可通过外网域名和端口访问实例，可使用查询实例列表接口获取外网域名和端口信息。
 
